@@ -1,9 +1,9 @@
 import os
 import random
-from typing import Optional
+from typing import Optional, List
 
-from domain.motorcycle_model.motorcycle_model import MotorcycleModel
-from domain.motorcycle_model.motorcycle_model_workbook import MotorcycleModelWorkbook
+from xlsx_lib.domain.motorcycle_model.motorcycle_model import MotorcycleModel
+from xlsx_lib.domain.motorcycle_model.motorcycle_model_workbook import MotorcycleModelWorkbook
 import glob
 
 
@@ -14,18 +14,18 @@ def create_motorcycle_model(filename: str, directory: Optional[str] = None):
     ).motorcycle_model
 
 
-def create_all_models() -> list[MotorcycleModel]:
-    filenames: list[str] = glob.glob("./files/*.xlsx", recursive=True)
+def create_all_models() -> List[MotorcycleModel]:
+    filenames: List[str] = glob.glob("./xlsx_lib/files/*.xlsx", recursive=True)
 
-    models: list[MotorcycleModel] = list()
+    models: List[MotorcycleModel] = list()
     # TODO: Create directory name
 
-    directory_name: str = f"./json/{random.randint(0, 999)}"
+    directory_name: str = f"./xlsx_lib/json/{random.randint(0, 999)}"
 
     try:
         os.mkdir(directory_name)
-    except OSError:
-        print("caca")
+    except OSError as error:
+        print(error)
 
     for filename in filenames:
         create_motorcycle_model(
