@@ -11,7 +11,7 @@ from xlsx_lib.domain.electronic.electronic_element import ElectronicElement
 
 
 # TODO: Sort conditions by usage
-from modules.format_cell_value import format_cell_value
+from xlsx_lib.modules.format_cell_value import format_cell_value
 
 
 def get_electronic_cell_value_type(cell: Cell) -> ElectronicValueTypes:
