@@ -1,3 +1,5 @@
+from typing import List
+
 from xlsx_lib.domain.electronic.component_attribute import ComponentAttribute
 
 
@@ -5,7 +7,7 @@ class ElementComponent:
     name: str
     value: str
     observations: str
-    attributes: list[ComponentAttribute]
+    attributes: List[ComponentAttribute]
 
     def __init__(
             self,
