@@ -10,7 +10,7 @@ from xlsx_lib.domain.engine.section_element import SectionElement
 from xlsx_lib.domain.engine.element_attribute import ElementAttribute
 
 from xlsx_lib.domain.engine.engine_cell_value_types import EngineCellValueTypes
-from modules.format_cell_value import format_cell_value
+from xlsx_lib.modules.format_cell_value import format_cell_value
 
 
 def get_engine_cell_value_type(cell: Cell) -> EngineCellValueTypes:
