@@ -1,3 +1,5 @@
+from typing import List
+
 from xlsx_lib.domain.engine.element_attribute import ElementAttribute
 
 
@@ -5,7 +7,7 @@ class SectionElement:
     name: str
     value: str
     observations: str
-    element_attributes: list[ElementAttribute]
+    element_attributes: List[ElementAttribute]
 
     def __init__(
             self,
