@@ -12,5 +12,5 @@ class ComponentPartScrew:
     ):
         self.name: str = name
         self.tightening_torque: str = tightening_torque
-        self.steps: List[TighteningTorqueStep] = List[TighteningTorqueStep]()
+        self.steps: List[TighteningTorqueStep] = list()
         self.detail: str = detail
