@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, List
 
 from openpyxl.cell import Cell
 from openpyxl.worksheet.worksheet import Worksheet
@@ -18,10 +18,10 @@ class TighteningTorquesSheet(Sheet):
             self,
             start_col: int = 0,
             start_row: int = 2,
-    ) -> list[Component]:
+    ) -> List[Component]:
         row_index = start_row
 
-        components: list[Component] = list()
+        components: List[Component] = list()
 
         while True:
             cell: Cell = self.sheet_reader.read_cell(start_col, row_index)
@@ -34,7 +34,7 @@ class TighteningTorquesSheet(Sheet):
                     end_row=row_index+4,
                 )
 
-                matches: list[str] = [value for value in values if value is not None]
+                matches: List[str] = [value for value in values if value is not None]
 
                 if len(matches) == 0:
                     break
@@ -89,7 +89,7 @@ class TighteningTorquesSheet(Sheet):
             col: int,
             row: int
     ) -> ComponentPartScrew:
-        values: list[str] = self.sheet_reader.read_cells_values(col, col+1, row, row)
+        values: List[str] = self.sheet_reader.read_cells_values(col, col + 1, row, row)
 
         tightening_torque: str = values[1]
 
@@ -108,7 +108,7 @@ class TighteningTorquesSheet(Sheet):
             col: int,
             row: int
     ) -> TighteningTorqueStep:
-        values: list[str] = self.sheet_reader.read_cells_values(col, col + 1, row, row)
+        values: List[str] = self.sheet_reader.read_cells_values(col, col + 1, row, row)
 
         return TighteningTorqueStep(
             name=values[0],
